@@ -38,30 +38,23 @@
 
 G_DEFINE_INTERFACE(GeditAppActivatable, gedit_app_activatable, G_TYPE_OBJECT)
 
-void
+static void
 gedit_app_activatable_default_init (GeditAppActivatableInterface *iface)
 {
-	static gboolean initialized = FALSE;
-
-	if (!initialized)
-	{
-		/**
-		 * GeditAppActivatable:app:
-		 *
-		 * The app property contains the gedit app for this
-		 * #GeditAppActivatable instance.
-		 */
-		g_object_interface_install_property (iface,
-		                                     g_param_spec_object ("app",
-		                                                          "App",
-		                                                          "The gedit app",
-		                                                          GEDIT_TYPE_APP,
-		                                                          G_PARAM_READWRITE |
-		                                                          G_PARAM_CONSTRUCT_ONLY |
-		                                                          G_PARAM_STATIC_STRINGS));
-
-		initialized = TRUE;
-	}
+	/**
+	 * GeditAppActivatable:app:
+	 *
+	 * The app property contains the gedit app for this
+	 * #GeditAppActivatable instance.
+	 */
+	g_object_interface_install_property (iface,
+	                                     g_param_spec_object ("app",
+	                                                          "App",
+	                                                          "The gedit app",
+	                                                          GEDIT_TYPE_APP,
+	                                                          G_PARAM_READWRITE |
+	                                                          G_PARAM_CONSTRUCT_ONLY |
+	                                                          G_PARAM_STATIC_STRINGS));
 }
 
 /**
