@@ -49,6 +49,7 @@
 #include "gedit-commands.h"
 #include "gedit-preferences-dialog.h"
 #include "gedit-tab.h"
+#include "gedit-tab-private.h"
 
 #ifndef ENABLE_GVFS_METADATA
 #include "gedit-metadata-manager.h"
@@ -64,7 +65,7 @@ enum
 	PROP_LOCKDOWN
 };
 
-struct _GeditAppPrivate
+typedef struct
 {
 	GeditPluginsEngine *engine;
 
@@ -97,7 +98,7 @@ struct _GeditAppPrivate
 	gint line_position;
 	gint column_position;
 	GApplicationCommandLine *command_line;
-};
+} GeditAppPrivate;
 
 static const GOptionEntry options[] =
 {
@@ -170,32 +171,35 @@ G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE (GeditApp, gedit_app, GTK_TYPE_APPLICATION)
 static void
 gedit_app_dispose (GObject *object)
 {
-	GeditApp *app = GEDIT_APP (object);
+	GeditAppPrivate *priv;
 
-	g_clear_object (&app->priv->ui_settings);
-	g_clear_object (&app->priv->window_settings);
-	g_clear_object (&app->priv->settings);
+	priv = gedit_app_get_instance_private (GEDIT_APP (object));
 
-	g_clear_object (&app->priv->page_setup);
-	g_clear_object (&app->priv->print_settings);
+	g_clear_object (&priv->ui_settings);
+	g_clear_object (&priv->window_settings);
+	g_clear_object (&priv->settings);
+
+	g_clear_object (&priv->page_setup);
+	g_clear_object (&priv->print_settings);
 
 	/* Note that unreffing the extensions will automatically remove
-	   all extensions which in turn will deactivate the extension */
-	g_clear_object (&app->priv->extensions);
+	 * all extensions which in turn will deactivate the extension
+	 */
+	g_clear_object (&priv->extensions);
 
-	g_clear_object (&app->priv->engine);
+	g_clear_object (&priv->engine);
 
-	if (app->priv->theme_provider != NULL)
+	if (priv->theme_provider != NULL)
 	{
 		gtk_style_context_remove_provider_for_screen (gdk_screen_get_default (),
-		                                              GTK_STYLE_PROVIDER (app->priv->theme_provider));
-		g_clear_object (&app->priv->theme_provider);
+		                                              GTK_STYLE_PROVIDER (priv->theme_provider));
+		g_clear_object (&priv->theme_provider);
 	}
 
-	g_clear_object (&app->priv->window_menu);
-	g_clear_object (&app->priv->notebook_menu);
-	g_clear_object (&app->priv->tab_width_menu);
-	g_clear_object (&app->priv->line_col_menu);
+	g_clear_object (&priv->window_menu);
+	g_clear_object (&priv->notebook_menu);
+	g_clear_object (&priv->tab_width_menu);
+	g_clear_object (&priv->line_col_menu);
 
 	G_OBJECT_CLASS (gedit_app_parent_class)->dispose (object);
 }
@@ -390,21 +394,16 @@ static void
 set_command_line_wait (GeditApp *app,
 		       GeditTab *tab)
 {
+	GeditAppPrivate *priv;
+
+	priv = gedit_app_get_instance_private (app);
+
 	g_object_set_data_full (G_OBJECT (tab),
 	                        "GeditTabCommandLineWait",
-	                        g_object_ref (app->priv->command_line),
+	                        g_object_ref (priv->command_line),
 	                        (GDestroyNotify)g_object_unref);
 }
 
-static void
-set_command_line_wait_doc (GeditDocument *doc,
-			   GeditApp      *app)
-{
-	GeditTab *tab = gedit_tab_get_from_document (doc);
-
-	set_command_line_wait (app, tab);
-}
-
 static void
 open_files (GApplication            *application,
 	    gboolean                 new_window,
@@ -475,7 +474,7 @@ open_files (GApplication            *application,
 
 		if (command_line)
 		{
-			g_slist_foreach (loaded, (GFunc)set_command_line_wait_doc, GEDIT_APP (application));
+			g_slist_foreach (loaded, (GFunc)set_command_line_wait, NULL);
 		}
 		g_slist_free (loaded);
 	}
@@ -669,6 +668,10 @@ theme_changed (GtkSettings *settings,
 	       GParamSpec  *pspec,
 	       GeditApp    *app)
 {
+	GeditAppPrivate *priv;
+
+	priv = gedit_app_get_instance_private (app);
+
 	gchar *theme, *lc_theme, *theme_css;
 
 	g_object_get (settings, "gtk-theme-name", &theme, NULL);
@@ -678,14 +681,14 @@ theme_changed (GtkSettings *settings,
 	theme_css = g_strdup_printf ("gedit.%s.css", lc_theme);
 	g_free (lc_theme);
 
-	if (app->priv->theme_provider != NULL)
+	if (priv->theme_provider != NULL)
 	{
 		gtk_style_context_remove_provider_for_screen (gdk_screen_get_default (),
-		                                              GTK_STYLE_PROVIDER (app->priv->theme_provider));
-		g_clear_object (&app->priv->theme_provider);
+		                                              GTK_STYLE_PROVIDER (priv->theme_provider));
+		g_clear_object (&priv->theme_provider);
 	}
 
-	app->priv->theme_provider = load_css_from_resource (theme_css, FALSE);
+	priv->theme_provider = load_css_from_resource (theme_css, FALSE);
 
 	g_free (theme_css);
 }
@@ -713,26 +716,32 @@ get_menu_model (GeditApp   *app,
 }
 
 static void
-add_accelerator (GeditApp    *app,
-                 const gchar *action_name,
-                 const gchar *accel)
+add_accelerator (GtkApplication *app,
+                 const gchar    *action_name,
+                 const gchar    *accel)
 {
 	const gchar *vaccels[] = {
 		accel,
 		NULL
 	};
 
-	gtk_application_set_accels_for_action (GTK_APPLICATION (app), action_name, vaccels);
+	gtk_application_set_accels_for_action (app, action_name, vaccels);
 }
 
 static void
 gedit_app_startup (GApplication *application)
 {
-	GeditApp *app = GEDIT_APP (application);
+	GeditAppPrivate *priv;
 	GtkCssProvider *css_provider;
 	GtkSourceStyleSchemeManager *manager;
 	const gchar *dir;
 	gchar *icon_dir;
+#ifndef ENABLE_GVFS_METADATA
+	const gchar *cache_dir;
+	gchar *metadata_filename;
+#endif
+
+	priv = gedit_app_get_instance_private (GEDIT_APP (application));
 
 	G_APPLICATION_CLASS (gedit_app_parent_class)->startup (application);
 
@@ -748,71 +757,74 @@ gedit_app_startup (GApplication *application)
 	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (), icon_dir);
 	g_free (icon_dir);
 
-	setup_theme_extensions (app);
+	setup_theme_extensions (GEDIT_APP (application));
 
 #ifndef ENABLE_GVFS_METADATA
-	gedit_metadata_manager_init ();
+	cache_dir = gedit_dirs_get_user_cache_dir ();
+	metadata_filename = g_build_filename (cache_dir, "gedit-metadata.xml", NULL);
+	gedit_metadata_manager_init (metadata_filename);
+	g_free (metadata_filename);
 #endif
 
 	/* Load settings */
-	app->priv->settings = gedit_settings_new ();
-	app->priv->ui_settings = g_settings_new ("org.gnome.gedit.preferences.ui");
-	app->priv->window_settings = g_settings_new ("org.gnome.gedit.state.window");
+	priv->settings = gedit_settings_new ();
+	priv->ui_settings = g_settings_new ("org.gnome.gedit.preferences.ui");
+	priv->window_settings = g_settings_new ("org.gnome.gedit.state.window");
 
 	/* initial lockdown state */
-	app->priv->lockdown = gedit_settings_get_lockdown (GEDIT_SETTINGS (app->priv->settings));
+	priv->lockdown = gedit_settings_get_lockdown (GEDIT_SETTINGS (priv->settings));
 
-	g_action_map_add_action_entries (G_ACTION_MAP (app),
+	g_action_map_add_action_entries (G_ACTION_MAP (application),
 	                                 app_entries,
 	                                 G_N_ELEMENTS (app_entries),
-	                                 app);
+	                                 application);
 
 	/* menus */
-	app->priv->window_menu = gtk_application_get_menubar (GTK_APPLICATION (app));
+	priv->window_menu = gtk_application_get_menubar (GTK_APPLICATION (application));
 
-	if (app->priv->window_menu == NULL)
+	if (priv->window_menu == NULL)
 	{
-		app->priv->window_menu = get_menu_model (app, "gear-menu");
+		priv->window_menu = get_menu_model (GEDIT_APP (application), "gear-menu");
 	}
 	else
 	{
-		g_object_ref (app->priv->window_menu);
+		g_object_ref (priv->window_menu);
 	}
 
-	app->priv->notebook_menu = get_menu_model (app, "notebook-menu");
-	app->priv->tab_width_menu = get_menu_model (app, "tab-width-menu");
-	app->priv->line_col_menu = get_menu_model (app, "line-col-menu");
+	priv->notebook_menu = get_menu_model (GEDIT_APP (application), "notebook-menu");
+	priv->tab_width_menu = get_menu_model (GEDIT_APP (application), "tab-width-menu");
+	priv->line_col_menu = get_menu_model (GEDIT_APP (application), "line-col-menu");
 
 	/* Accelerators */
-	add_accelerator (app, "app.new-window", "<Primary>N");
-	add_accelerator (app, "app.quit", "<Primary>Q");
-	add_accelerator (app, "app.help", "F1");
+	add_accelerator (GTK_APPLICATION (application), "app.new-window", "<Primary>N");
+	add_accelerator (GTK_APPLICATION (application), "app.quit", "<Primary>Q");
+	add_accelerator (GTK_APPLICATION (application), "app.help", "F1");
 
-	add_accelerator (app, "win.gear-menu", "F10");
-	add_accelerator (app, "win.open", "<Primary>O");
-	add_accelerator (app, "win.save", "<Primary>S");
-	add_accelerator (app, "win.save-as", "<Primary><Shift>S");
-	add_accelerator (app, "win.save-all", "<Primary><Shift>L");
-	add_accelerator (app, "win.new-tab", "<Primary>T");
-	add_accelerator (app, "win.reopen-closed-tab", "<Primary><Shift>T");
-	add_accelerator (app, "win.close", "<Primary>W");
-	add_accelerator (app, "win.close-all", "<Primary><Shift>W");
-	add_accelerator (app, "win.print", "<Primary>P");
-	add_accelerator (app, "win.find", "<Primary>F");
-	add_accelerator (app, "win.find-next", "<Primary>G");
-	add_accelerator (app, "win.find-prev", "<Primary><Shift>G");
-	add_accelerator (app, "win.replace", "<Primary>H");
-	add_accelerator (app, "win.clear-highlight", "<Primary><Shift>K");
-	add_accelerator (app, "win.goto-line", "<Primary>I");
-	add_accelerator (app, "win.focus-active-view", "Escape");
-	add_accelerator (app, "win.side-panel", "F9");
-	add_accelerator (app, "win.bottom-panel", "<Primary>F9");
-	add_accelerator (app, "win.fullscreen", "F11");
-	add_accelerator (app, "win.new-tab-group", "<Primary><Alt>N");
-	add_accelerator (app, "win.previous-tab-group", "<Primary><Shift><Alt>Page_Up");
-	add_accelerator (app, "win.next-tab-group", "<Primary><Shift><Alt>Page_Down");
-	add_accelerator (app, "win.previous-document", "<Primary><Alt>Page_Up");
-	add_accelerator (app, "win.next-document", "<Primary><Alt>Page_Down");
+	add_accelerator (GTK_APPLICATION (application), "win.gear-menu", "F10");
+	add_accelerator (GTK_APPLICATION (application), "win.open", "<Primary>O");
+	add_accelerator (GTK_APPLICATION (application), "win.save", "<Primary>S");
+	add_accelerator (GTK_APPLICATION (application), "win.save-as", "<Primary><Shift>S");
+	add_accelerator (GTK_APPLICATION (application), "win.save-all", "<Primary><Shift>L");
+	add_accelerator (GTK_APPLICATION (application), "win.new-tab", "<Primary>T");
+	add_accelerator (GTK_APPLICATION (application), "win.reopen-closed-tab", "<Primary><Shift>T");
+	add_accelerator (GTK_APPLICATION (application), "win.close", "<Primary>W");
+	add_accelerator (GTK_APPLICATION (application), "win.close-all", "<Primary><Shift>W");
+	add_accelerator (GTK_APPLICATION (application), "win.print", "<Primary>P");
+	add_accelerator (GTK_APPLICATION (application), "win.find", "<Primary>F");
+	add_accelerator (GTK_APPLICATION (application), "win.find-next", "<Primary>G");
+	add_accelerator (GTK_APPLICATION (application), "win.find-prev", "<Primary><Shift>G");
+	add_accelerator (GTK_APPLICATION (application), "win.replace", "<Primary>H");
+	add_accelerator (GTK_APPLICATION (application), "win.clear-highlight", "<Primary><Shift>K");
+	add_accelerator (GTK_APPLICATION (application), "win.goto-line", "<Primary>I");
+	add_accelerator (GTK_APPLICATION (application), "win.focus-active-view", "Escape");
+	add_accelerator (GTK_APPLICATION (application), "win.side-panel", "F9");
+	add_accelerator (GTK_APPLICATION (application), "win.bottom-panel", "<Primary>F9");
+	add_accelerator (GTK_APPLICATION (application), "win.fullscreen", "F11");
+	add_accelerator (GTK_APPLICATION (application), "win.new-tab-group", "<Primary><Alt>N");
+	add_accelerator (GTK_APPLICATION (application), "win.previous-tab-group", "<Primary><Shift><Alt>Page_Up");
+	add_accelerator (GTK_APPLICATION (application), "win.next-tab-group", "<Primary><Shift><Alt>Page_Down");
+	add_accelerator (GTK_APPLICATION (application), "win.previous-document", "<Primary><Alt>Page_Up");
+	add_accelerator (GTK_APPLICATION (application), "win.next-document", "<Primary><Alt>Page_Down");
 
 	load_accels ();
 
@@ -830,31 +842,33 @@ gedit_app_startup (GApplication *application)
 	gtk_source_style_scheme_manager_append_search_path (manager,
 	                                                    gedit_dirs_get_user_styles_dir ());
 
-	app->priv->engine = gedit_plugins_engine_get_default ();
-	app->priv->extensions = peas_extension_set_new (PEAS_ENGINE (app->priv->engine),
-	                                                GEDIT_TYPE_APP_ACTIVATABLE,
-	                                                "app", app,
-	                                                NULL);
+	priv->engine = gedit_plugins_engine_get_default ();
+	priv->extensions = peas_extension_set_new (PEAS_ENGINE (priv->engine),
+	                                           GEDIT_TYPE_APP_ACTIVATABLE,
+	                                           "app", GEDIT_APP (application),
+	                                           NULL);
 
-	g_signal_connect (app->priv->extensions,
+	g_signal_connect (priv->extensions,
 	                  "extension-added",
 	                  G_CALLBACK (extension_added),
-	                  app);
+	                  application);
 
-	g_signal_connect (app->priv->extensions,
+	g_signal_connect (priv->extensions,
 	                  "extension-removed",
 	                  G_CALLBACK (extension_removed),
-	                  app);
+	                  application);
 
-	peas_extension_set_foreach (app->priv->extensions,
+	peas_extension_set_foreach (priv->extensions,
 	                            (PeasExtensionSetForeachFunc) extension_added,
-	                            app);
+	                            application);
 }
 
 static void
 gedit_app_activate (GApplication *application)
 {
-	GeditAppPrivate *priv = GEDIT_APP (application)->priv;
+	GeditAppPrivate *priv;
+
+	priv = gedit_app_get_instance_private (GEDIT_APP (application));
 
 	open_files (application,
 	            priv->new_window,
@@ -871,7 +885,9 @@ gedit_app_activate (GApplication *application)
 static void
 clear_options (GeditApp *app)
 {
-	GeditAppPrivate *priv = app->priv;
+	GeditAppPrivate *priv;
+
+	priv = gedit_app_get_instance_private (app);
 
 	g_free (priv->geometry);
 	g_clear_object (&priv->stdin_stream);
@@ -921,7 +937,7 @@ gedit_app_command_line (GApplication            *application,
 	const gchar *encoding_charset;
 	const gchar **remaining_args;
 
-	priv = GEDIT_APP (application)->priv;
+	priv = gedit_app_get_instance_private (GEDIT_APP (application));
 
 	options = g_application_command_line_get_options_dict (cl);
 
@@ -1140,24 +1156,28 @@ get_page_setup_file (void)
 static void
 save_page_setup (GeditApp *app)
 {
-	gchar *filename;
-	GError *error = NULL;
+	GeditAppPrivate *priv;
 
-	if (app->priv->page_setup == NULL)
-		return;
+	priv = gedit_app_get_instance_private (app);
 
-	filename = get_page_setup_file ();
-
-	gtk_page_setup_to_file (app->priv->page_setup,
-				filename,
-				&error);
-	if (error)
+	if (priv->page_setup != NULL)
 	{
-		g_warning ("%s", error->message);
-		g_error_free (error);
-	}
+		gchar *filename;
+		GError *error = NULL;
 
-	g_free (filename);
+		filename = get_page_setup_file ();
+
+		gtk_page_setup_to_file (priv->page_setup,
+					filename,
+					&error);
+		if (error)
+		{
+			g_warning ("%s", error->message);
+			g_error_free (error);
+		}
+
+		g_free (filename);
+	}
 }
 
 static gchar *
@@ -1181,24 +1201,28 @@ get_print_settings_file (void)
 static void
 save_print_settings (GeditApp *app)
 {
-	gchar *filename;
-	GError *error = NULL;
+	GeditAppPrivate *priv;
 
-	if (app->priv->print_settings == NULL)
-		return;
+	priv = gedit_app_get_instance_private (app);
 
-	filename = get_print_settings_file ();
-
-	gtk_print_settings_to_file (app->priv->print_settings,
-				    filename,
-				    &error);
-	if (error)
+	if (priv->print_settings != NULL)
 	{
-		g_warning ("%s", error->message);
-		g_error_free (error);
-	}
+		gchar *filename;
+		GError *error = NULL;
 
-	g_free (filename);
+		filename = get_print_settings_file ();
+
+		gtk_print_settings_to_file (priv->print_settings,
+					    filename,
+					    &error);
+		if (error)
+		{
+			g_warning ("%s", error->message);
+			g_error_free (error);
+		}
+
+		g_free (filename);
+	}
 }
 
 static void
@@ -1299,15 +1323,17 @@ gedit_app_class_init (GeditAppClass *klass)
 static void
 load_page_setup (GeditApp *app)
 {
+	GeditAppPrivate *priv;
 	gchar *filename;
 	GError *error = NULL;
 
-	g_return_if_fail (app->priv->page_setup == NULL);
+	priv = gedit_app_get_instance_private (app);
+
+	g_return_if_fail (priv->page_setup == NULL);
 
 	filename = get_page_setup_file ();
 
-	app->priv->page_setup = gtk_page_setup_new_from_file (filename,
-							      &error);
+	priv->page_setup = gtk_page_setup_new_from_file (filename, &error);
 	if (error)
 	{
 		/* Ignore file not found error */
@@ -1323,22 +1349,26 @@ load_page_setup (GeditApp *app)
 	g_free (filename);
 
 	/* fall back to default settings */
-	if (app->priv->page_setup == NULL)
-		app->priv->page_setup = gtk_page_setup_new ();
+	if (priv->page_setup == NULL)
+	{
+		priv->page_setup = gtk_page_setup_new ();
+	}
 }
 
 static void
 load_print_settings (GeditApp *app)
 {
+	GeditAppPrivate *priv;
 	gchar *filename;
 	GError *error = NULL;
 
-	g_return_if_fail (app->priv->print_settings == NULL);
+	priv = gedit_app_get_instance_private (app);
+
+	g_return_if_fail (priv->print_settings == NULL);
 
 	filename = get_print_settings_file ();
 
-	app->priv->print_settings = gtk_print_settings_new_from_file (filename,
-								      &error);
+	priv->print_settings = gtk_print_settings_new_from_file (filename, &error);
 	if (error)
 	{
 		/* Ignore file not found error */
@@ -1354,8 +1384,10 @@ load_print_settings (GeditApp *app)
 	g_free (filename);
 
 	/* fall back to default settings */
-	if (app->priv->print_settings == NULL)
-		app->priv->print_settings = gtk_print_settings_new ();
+	if (priv->print_settings == NULL)
+	{
+		priv->print_settings = gtk_print_settings_new ();
+	}
 }
 
 static void
@@ -1394,16 +1426,18 @@ get_network_available (GNetworkMonitor *monitor,
 static void
 gedit_app_init (GeditApp *app)
 {
-	app->priv = gedit_app_get_instance_private (app);
+	GeditAppPrivate *priv;
+
+	priv = gedit_app_get_instance_private (app);
 
 	g_set_application_name ("gedit");
 	gtk_window_set_default_icon_name ("accessories-text-editor");
 
-	app->priv->monitor = g_network_monitor_get_default ();
-	g_signal_connect (app->priv->monitor,
-			  "network-changed",
-			  G_CALLBACK (get_network_available),
-			  app);
+	priv->monitor = g_network_monitor_get_default ();
+	g_signal_connect (priv->monitor,
+	                  "network-changed",
+	                  G_CALLBACK (get_network_available),
+	                  app);
 
 	g_application_add_main_option_entries (G_APPLICATION (app), options);
 
@@ -1441,6 +1475,7 @@ GeditWindow *
 gedit_app_create_window (GeditApp  *app,
 			 GdkScreen *screen)
 {
+	GeditAppPrivate *priv;
 	GeditWindow *window;
 	gchar *role;
 	GdkWindowState state;
@@ -1448,6 +1483,8 @@ gedit_app_create_window (GeditApp  *app,
 
 	gedit_debug (DEBUG_APP);
 
+	priv = gedit_app_get_instance_private (app);
+
 	window = GEDIT_APP_GET_CLASS (app)->create_window (app);
 
 	if (screen != NULL)
@@ -1459,12 +1496,12 @@ gedit_app_create_window (GeditApp  *app,
 	gtk_window_set_role (GTK_WINDOW (window), role);
 	g_free (role);
 
-	state = g_settings_get_int (app->priv->window_settings,
-				    GEDIT_SETTINGS_WINDOW_STATE);
+	state = g_settings_get_int (priv->window_settings,
+	                            GEDIT_SETTINGS_WINDOW_STATE);
 
-	g_settings_get (app->priv->window_settings,
-			GEDIT_SETTINGS_WINDOW_SIZE,
-			"(ii)", &w, &h);
+	g_settings_get (priv->window_settings,
+	                GEDIT_SETTINGS_WINDOW_SIZE,
+	                "(ii)", &w, &h);
 
 	gtk_window_set_default_size (GTK_WINDOW (window), w, h);
 
@@ -1591,9 +1628,13 @@ gedit_app_get_views (GeditApp *app)
 GeditLockdownMask
 gedit_app_get_lockdown (GeditApp *app)
 {
+	GeditAppPrivate *priv;
+
 	g_return_val_if_fail (GEDIT_IS_APP (app), GEDIT_LOCKDOWN_ALL);
 
-	return app->priv->lockdown;
+	priv = gedit_app_get_instance_private (app);
+
+	return priv->lockdown;
 }
 
 gboolean
@@ -1682,17 +1723,18 @@ find_extension_point_section (GMenuModel  *model,
 static void
 app_lockdown_changed (GeditApp *app)
 {
+	GeditAppPrivate *priv;
 	GList *windows, *l;
 
+	priv = gedit_app_get_instance_private (app);
+
 	windows = gtk_application_get_windows (GTK_APPLICATION (app));
 	for (l = windows; l != NULL; l = g_list_next (l))
 	{
-		GtkWindow *window = l->data;
-
-		if (GEDIT_IS_WINDOW (window))
+		if (GEDIT_IS_WINDOW (l->data))
 		{
-			_gedit_window_set_lockdown (GEDIT_WINDOW (window),
-				                    app->priv->lockdown);
+			_gedit_window_set_lockdown (GEDIT_WINDOW (l->data),
+			                            priv->lockdown);
 		}
 	}
 
@@ -1703,10 +1745,13 @@ void
 _gedit_app_set_lockdown (GeditApp          *app,
 			 GeditLockdownMask  lockdown)
 {
+	GeditAppPrivate *priv;
+
 	g_return_if_fail (GEDIT_IS_APP (app));
 
-	app->priv->lockdown = lockdown;
+	priv = gedit_app_get_instance_private (app);
 
+	priv->lockdown = lockdown;
 	app_lockdown_changed (app);
 }
 
@@ -1715,12 +1760,20 @@ _gedit_app_set_lockdown_bit (GeditApp          *app,
 			     GeditLockdownMask  bit,
 			     gboolean           value)
 {
+	GeditAppPrivate *priv;
+
 	g_return_if_fail (GEDIT_IS_APP (app));
 
+	priv = gedit_app_get_instance_private (app);
+
 	if (value)
-		app->priv->lockdown |= bit;
+	{
+		priv->lockdown |= bit;
+	}
 	else
-		app->priv->lockdown &= ~bit;
+	{
+		priv->lockdown &= ~bit;
+	}
 
 	app_lockdown_changed (app);
 }
@@ -1729,105 +1782,151 @@ _gedit_app_set_lockdown_bit (GeditApp          *app,
 GtkPageSetup *
 _gedit_app_get_default_page_setup (GeditApp *app)
 {
+	GeditAppPrivate *priv;
+
 	g_return_val_if_fail (GEDIT_IS_APP (app), NULL);
 
-	if (app->priv->page_setup == NULL)
-		load_page_setup (app);
+	priv = gedit_app_get_instance_private (app);
 
-	return gtk_page_setup_copy (app->priv->page_setup);
+	if (priv->page_setup == NULL)
+	{
+		load_page_setup (app);
+	}
+
+	return gtk_page_setup_copy (priv->page_setup);
 }
 
 void
 _gedit_app_set_default_page_setup (GeditApp     *app,
 				   GtkPageSetup *page_setup)
 {
+	GeditAppPrivate *priv;
+
 	g_return_if_fail (GEDIT_IS_APP (app));
 	g_return_if_fail (GTK_IS_PAGE_SETUP (page_setup));
 
-	if (app->priv->page_setup != NULL)
-		g_object_unref (app->priv->page_setup);
+	priv = gedit_app_get_instance_private (app);
 
-	app->priv->page_setup = g_object_ref (page_setup);
+	if (priv->page_setup != NULL)
+	{
+		g_object_unref (priv->page_setup);
+	}
+
+	priv->page_setup = g_object_ref (page_setup);
 }
 
 /* Returns a copy */
 GtkPrintSettings *
 _gedit_app_get_default_print_settings (GeditApp *app)
 {
+	GeditAppPrivate *priv;
+
 	g_return_val_if_fail (GEDIT_IS_APP (app), NULL);
 
-	if (app->priv->print_settings == NULL)
-		load_print_settings (app);
+	priv = gedit_app_get_instance_private (app);
 
-	return gtk_print_settings_copy (app->priv->print_settings);
+	if (priv->print_settings == NULL)
+	{
+		load_print_settings (app);
+	}
+
+	return gtk_print_settings_copy (priv->print_settings);
 }
 
 void
 _gedit_app_set_default_print_settings (GeditApp         *app,
 				       GtkPrintSettings *settings)
 {
+	GeditAppPrivate *priv;
+
 	g_return_if_fail (GEDIT_IS_APP (app));
 	g_return_if_fail (GTK_IS_PRINT_SETTINGS (settings));
 
-	if (app->priv->print_settings != NULL)
-		g_object_unref (app->priv->print_settings);
+	priv = gedit_app_get_instance_private (app);
 
-	app->priv->print_settings = g_object_ref (settings);
+	if (priv->print_settings != NULL)
+	{
+		g_object_unref (priv->print_settings);
+	}
+
+	priv->print_settings = g_object_ref (settings);
 }
 
 GObject *
 _gedit_app_get_settings (GeditApp *app)
 {
+	GeditAppPrivate *priv;
+
 	g_return_val_if_fail (GEDIT_IS_APP (app), NULL);
 
-	return app->priv->settings;
+	priv = gedit_app_get_instance_private (app);
+
+	return priv->settings;
 }
 
 GMenuModel *
 _gedit_app_get_window_menu (GeditApp *app)
 {
+	GeditAppPrivate *priv;
+
 	g_return_val_if_fail (GEDIT_IS_APP (app), NULL);
 
-	return app->priv->window_menu;
+	priv = gedit_app_get_instance_private (app);
+
+	return priv->window_menu;
 }
 
 GMenuModel *
 _gedit_app_get_notebook_menu (GeditApp *app)
 {
+	GeditAppPrivate *priv;
+
 	g_return_val_if_fail (GEDIT_IS_APP (app), NULL);
 
-	return app->priv->notebook_menu;
+	priv = gedit_app_get_instance_private (app);
+
+	return priv->notebook_menu;
 }
 
 GMenuModel *
 _gedit_app_get_tab_width_menu (GeditApp *app)
 {
+	GeditAppPrivate *priv;
+
 	g_return_val_if_fail (GEDIT_IS_APP (app), NULL);
 
-	return app->priv->tab_width_menu;
+	priv = gedit_app_get_instance_private (app);
+
+	return priv->tab_width_menu;
 }
 
 GMenuModel *
 _gedit_app_get_line_col_menu (GeditApp *app)
 {
+	GeditAppPrivate *priv;
+
 	g_return_val_if_fail (GEDIT_IS_APP (app), NULL);
 
-	return app->priv->line_col_menu;
-}
+	priv = gedit_app_get_instance_private (app);
 
+	return priv->line_col_menu;
+}
 
 GeditMenuExtension *
 _gedit_app_extend_menu (GeditApp    *app,
                        const gchar *extension_point)
 {
+	GeditAppPrivate *priv;
 	GMenuModel *model;
 	GMenuModel *section;
 
 	g_return_val_if_fail (GEDIT_IS_APP (app), NULL);
 	g_return_val_if_fail (extension_point != NULL, NULL);
 
+	priv = gedit_app_get_instance_private (app);
+
 	/* First look in the window menu */
-	section = find_extension_point_section (app->priv->window_menu, extension_point);
+	section = find_extension_point_section (priv->window_menu, extension_point);
 
 	/* otherwise look in the app menu */
 	if (section == NULL)
