@@ -20,12 +20,7 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "gedit-debug.h"
-
 #include <stdio.h>
 
 #define ENABLE_PROFILING
