@@ -25,6 +25,8 @@
 #include "gedit-enum-types.h"
 #include "gedit-marshal.h"
 #include "gedit-settings.h"
+#include "gedit-tab-private.h"
+#include "gedit-tab.h"
 
 struct _GeditMultiNotebookPrivate
 {
