@@ -480,7 +480,6 @@ create_compositor (GeditPrintJob *job)
 	guint print_line_numbers;
 	gboolean print_header;
 	guint tab_width;
-	gdouble margin;
 
 	print_font_body = g_settings_get_string (job->priv->gsettings,
 						 GEDIT_SETTINGS_PRINT_FONT_BODY_PANGO);
@@ -521,17 +520,9 @@ create_compositor (GeditPrintJob *job)
 			      "header-font-name", print_font_header,
 			      NULL));
 
-	margin = g_settings_get_double (job->priv->gsettings, GEDIT_SETTINGS_PRINT_MARGIN_LEFT);
-	gtk_source_print_compositor_set_left_margin (job->priv->compositor, margin, GTK_UNIT_MM);
-
-	margin = g_settings_get_double (job->priv->gsettings, GEDIT_SETTINGS_PRINT_MARGIN_TOP);
-	gtk_source_print_compositor_set_top_margin (job->priv->compositor, margin, GTK_UNIT_MM);
-
-	margin = g_settings_get_double (job->priv->gsettings, GEDIT_SETTINGS_PRINT_MARGIN_RIGHT);
-	gtk_source_print_compositor_set_right_margin (job->priv->compositor, margin, GTK_UNIT_MM);
-
-	margin = g_settings_get_double (job->priv->gsettings, GEDIT_SETTINGS_PRINT_MARGIN_BOTTOM);
-	gtk_source_print_compositor_set_bottom_margin (job->priv->compositor, margin, GTK_UNIT_MM);
+	g_free (print_font_body);
+	g_free (print_font_header);
+	g_free (print_font_numbers);
 
 	if (print_header)
 	{
@@ -557,10 +548,6 @@ create_compositor (GeditPrintJob *job)
 		g_free (name_to_display);
 		g_free (left);
 	}
-
-	g_free (print_font_body);
-	g_free (print_font_header);
-	g_free (print_font_numbers);
 }
 
 static void
