@@ -28,6 +28,8 @@
 #include <gtk/gtk.h>
 
 #include "gedit-small-button.h"
+#include "gedit-tab.h"
+#include "gedit-tab-private.h"
 
 /* Signals */
 enum
@@ -42,8 +44,10 @@ enum
 	PROP_TAB
 };
 
-struct _GeditTabLabelPrivate
+struct _GeditTabLabel
 {
+	GtkBox parent_instance;
+
 	GeditTab *tab;
 
 	GtkWidget *close_button;
@@ -56,7 +60,7 @@ struct _GeditTabLabelPrivate
 
 static guint signals[LAST_SIGNAL] = { 0 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (GeditTabLabel, gedit_tab_label, GTK_TYPE_BOX)
+G_DEFINE_TYPE (GeditTabLabel, gedit_tab_label, GTK_TYPE_BOX)
 
 static void
 gedit_tab_label_finalize (GObject *object)
@@ -75,7 +79,7 @@ gedit_tab_label_set_property (GObject      *object,
 	switch (prop_id)
 	{
 		case PROP_TAB:
-			tab_label->priv->tab = GEDIT_TAB (g_value_get_object (value));
+			tab_label->tab = GEDIT_TAB (g_value_get_object (value));
 			break;
 
 		default:
@@ -95,7 +99,7 @@ gedit_tab_label_get_property (GObject    *object,
 	switch (prop_id)
 	{
 		case PROP_TAB:
-			g_value_set_object (value, tab_label->priv->tab);
+			g_value_set_object (value, tab_label->tab);
 			break;
 
 		default:
@@ -131,12 +135,12 @@ sync_name (GeditTab      *tab,
 {
 	gchar *str;
 
-	g_return_if_fail (tab == tab_label->priv->tab);
+	g_return_if_fail (tab == tab_label->tab);
 
 	str = _gedit_tab_get_name (tab);
 	g_return_if_fail (str != NULL);
 
-	gtk_label_set_text (GTK_LABEL (tab_label->priv->label), str);
+	gtk_label_set_text (GTK_LABEL (tab_label->label), str);
 	g_free (str);
 
 	sync_tip (tab, tab_label);
@@ -145,10 +149,10 @@ sync_name (GeditTab      *tab,
 static void
 update_close_button_sensitivity (GeditTabLabel *tab_label)
 {
-	GeditTabState state = gedit_tab_get_state (tab_label->priv->tab);
+	GeditTabState state = gedit_tab_get_state (tab_label->tab);
 
-	gtk_widget_set_sensitive (tab_label->priv->close_button,
-				  tab_label->priv->close_button_sensitive &&
+	gtk_widget_set_sensitive (tab_label->close_button,
+				  tab_label->close_button_sensitive &&
 				  (state != GEDIT_TAB_STATE_CLOSING) &&
 				  (state != GEDIT_TAB_STATE_SAVING)  &&
 				  (state != GEDIT_TAB_STATE_SHOWING_PRINT_PREVIEW) &&
@@ -164,7 +168,7 @@ sync_state (GeditTab      *tab,
 {
 	GeditTabState state;
 
-	g_return_if_fail (tab == tab_label->priv->tab);
+	g_return_if_fail (tab == tab_label->tab);
 
 	update_close_button_sensitivity (tab_label);
 
@@ -174,10 +178,10 @@ sync_state (GeditTab      *tab,
 	    (state == GEDIT_TAB_STATE_SAVING)    ||
 	    (state == GEDIT_TAB_STATE_REVERTING))
 	{
-		gtk_widget_hide (tab_label->priv->icon);
+		gtk_widget_hide (tab_label->icon);
 
-		gtk_widget_show (tab_label->priv->spinner);
-		gtk_spinner_start (GTK_SPINNER (tab_label->priv->spinner));
+		gtk_widget_show (tab_label->spinner);
+		gtk_spinner_start (GTK_SPINNER (tab_label->spinner));
 	}
 	else
 	{
@@ -187,20 +191,20 @@ sync_state (GeditTab      *tab,
 
 		if (pixbuf != NULL)
 		{
-			gtk_image_set_from_pixbuf (GTK_IMAGE (tab_label->priv->icon),
+			gtk_image_set_from_pixbuf (GTK_IMAGE (tab_label->icon),
 			                           pixbuf);
 
 			g_clear_object (&pixbuf);
 
-			gtk_widget_show (tab_label->priv->icon);
+			gtk_widget_show (tab_label->icon);
 		}
 		else
 		{
-			gtk_widget_hide (tab_label->priv->icon);
+			gtk_widget_hide (tab_label->icon);
 		}
 
-		gtk_spinner_stop (GTK_SPINNER (tab_label->priv->spinner));
-		gtk_widget_hide (tab_label->priv->spinner);
+		gtk_spinner_stop (GTK_SPINNER (tab_label->spinner));
+		gtk_widget_hide (tab_label->spinner);
 	}
 
 	/* sync tip since encoding is known only after load/save end */
@@ -212,22 +216,22 @@ gedit_tab_label_constructed (GObject *object)
 {
 	GeditTabLabel *tab_label = GEDIT_TAB_LABEL (object);
 
-	if (!tab_label->priv->tab)
+	if (!tab_label->tab)
 	{
 		g_critical ("The tab label was not properly constructed");
 		return;
 	}
 
-	sync_name (tab_label->priv->tab, NULL, tab_label);
-	sync_state (tab_label->priv->tab, NULL, tab_label);
+	sync_name (tab_label->tab, NULL, tab_label);
+	sync_state (tab_label->tab, NULL, tab_label);
 
-	g_signal_connect_object (tab_label->priv->tab,
+	g_signal_connect_object (tab_label->tab,
 				 "notify::name",
 				 G_CALLBACK (sync_name),
 				 tab_label,
 				 0);
 
-	g_signal_connect_object (tab_label->priv->tab,
+	g_signal_connect_object (tab_label->tab,
 				 "notify::state",
 				 G_CALLBACK (sync_state),
 				 tab_label,
@@ -236,6 +240,11 @@ gedit_tab_label_constructed (GObject *object)
 	G_OBJECT_CLASS (gedit_tab_label_parent_class)->constructed (object);
 }
 
+static void
+gedit_tab_label_close_clicked (GeditTabLabel *tab_label)
+{
+}
+
 static void
 gedit_tab_label_class_init (GeditTabLabelClass *klass)
 {
@@ -248,14 +257,13 @@ gedit_tab_label_class_init (GeditTabLabelClass *klass)
 	object_class->constructed = gedit_tab_label_constructed;
 
 	signals[CLOSE_CLICKED] =
-		g_signal_new ("close-clicked",
-			      G_OBJECT_CLASS_TYPE (object_class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GeditTabLabelClass, close_clicked),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE,
-			      0);
+		g_signal_new_class_handler ("close-clicked",
+		                            G_TYPE_FROM_CLASS (klass),
+		                            G_SIGNAL_RUN_LAST,
+		                            G_CALLBACK (gedit_tab_label_close_clicked),
+		                            NULL, NULL, NULL,
+		                            G_TYPE_NONE,
+		                            0);
 
 	g_object_class_install_property (object_class,
 					 PROP_TAB,
@@ -269,22 +277,20 @@ gedit_tab_label_class_init (GeditTabLabelClass *klass)
 	/* Bind class to template */
 	gtk_widget_class_set_template_from_resource (widget_class,
 	                                             "/org/gnome/gedit/ui/gedit-tab-label.ui");
-	gtk_widget_class_bind_template_child_private (widget_class, GeditTabLabel, spinner);
-	gtk_widget_class_bind_template_child_private (widget_class, GeditTabLabel, close_button);
-	gtk_widget_class_bind_template_child_private (widget_class, GeditTabLabel, icon);
-	gtk_widget_class_bind_template_child_private (widget_class, GeditTabLabel, label);
+	gtk_widget_class_bind_template_child (widget_class, GeditTabLabel, spinner);
+	gtk_widget_class_bind_template_child (widget_class, GeditTabLabel, close_button);
+	gtk_widget_class_bind_template_child (widget_class, GeditTabLabel, icon);
+	gtk_widget_class_bind_template_child (widget_class, GeditTabLabel, label);
 }
 
 static void
 gedit_tab_label_init (GeditTabLabel *tab_label)
 {
-	tab_label->priv = gedit_tab_label_get_instance_private (tab_label);
-
-	tab_label->priv->close_button_sensitive = TRUE;
+	tab_label->close_button_sensitive = TRUE;
 
 	gtk_widget_init_template (GTK_WIDGET (tab_label));
 
-	g_signal_connect (tab_label->priv->close_button,
+	g_signal_connect (tab_label->close_button,
 	                  "clicked",
 	                  G_CALLBACK (close_button_clicked_cb),
 	                  tab_label);
@@ -298,9 +304,9 @@ gedit_tab_label_set_close_button_sensitive (GeditTabLabel *tab_label,
 
 	sensitive = (sensitive != FALSE);
 
-	if (tab_label->priv->close_button_sensitive != sensitive)
+	if (tab_label->close_button_sensitive != sensitive)
 	{
-		tab_label->priv->close_button_sensitive = sensitive;
+		tab_label->close_button_sensitive = sensitive;
 		update_close_button_sensitivity (tab_label);
 	}
 }
@@ -310,7 +316,7 @@ gedit_tab_label_get_tab (GeditTabLabel *tab_label)
 {
 	g_return_val_if_fail (GEDIT_IS_TAB_LABEL (tab_label), NULL);
 
-	return tab_label->priv->tab;
+	return tab_label->tab;
 }
 
 GtkWidget *
