@@ -20,38 +20,17 @@
  * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 #include "gedit-utils.h"
 
-#include <errno.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <sys/time.h>
-#include <fcntl.h>
 #include <string.h>
-
-#include <glib.h>
 #include <glib/gi18n.h>
-#include <glib/gstdio.h>
-#include <gio/gio.h>
 
 /* For the workspace/viewport stuff */
 #ifdef GDK_WINDOWING_X11
 #include <gdk/gdkx.h>
-#include <X11/Xlib.h>
-#include <X11/Xutil.h>
 #include <X11/Xatom.h>
 #endif
 
-#ifdef G_OS_UNIX
-#include <unistd.h>
-#include <sys/stat.h>
-#endif
-
-#include "gedit-document.h"
 #include "gedit-debug.h"
 
 static void
@@ -1462,71 +1441,4 @@ gedit_utils_newline_type_to_string (GtkSourceNewlineType newline_type)
 	return NULL;
 }
 
-static gboolean
-data_exists (GSList         *list,
-	     const gpointer  data)
-{
-	for (; list != NULL; list = g_slist_next (list))
-	{
-		if (list->data == data)
-		{
-			return TRUE;
-		}
-	}
-
-	return FALSE;
-}
-
-GSList *
-_gedit_utils_encoding_strv_to_list (const gchar * const *enc_str)
-{
-	GSList *res = NULL;
-	gchar **p;
-
-	for (p = (gchar **)enc_str; p != NULL && *p != NULL; p++)
-	{
-		const gchar *charset = *p;
-		const GtkSourceEncoding *enc;
-
-		if (g_str_equal (charset, "CURRENT"))
-		{
-			g_get_charset (&charset);
-		}
-
-		g_return_val_if_fail (charset != NULL, NULL);
-		enc = gtk_source_encoding_get_from_charset (charset);
-
-		if (enc != NULL &&
-		    !data_exists (res, (gpointer)enc))
-		{
-			res = g_slist_prepend (res, (gpointer)enc);
-		}
-	}
-
-	return g_slist_reverse (res);
-}
-
-gchar **
-_gedit_utils_encoding_list_to_strv (const GSList *enc_list)
-{
-	GSList *l;
-	GPtrArray *array;
-
-	array = g_ptr_array_sized_new (g_slist_length ((GSList *)enc_list) + 1);
-
-	for (l = (GSList *)enc_list; l != NULL; l = g_slist_next (l))
-	{
-		const GtkSourceEncoding *enc = l->data;
-		const gchar *charset = gtk_source_encoding_get_charset (enc);
-
-		g_return_val_if_fail (charset != NULL, NULL);
-
-		g_ptr_array_add (array, g_strdup (charset));
-	}
-
-	g_ptr_array_add (array, NULL);
-
-	return (gchar **)g_ptr_array_free (array, FALSE);
-}
-
 /* ex:set ts=8 noet: */
