@@ -23,10 +23,6 @@
 #ifndef __GEDIT_UTILS_H__
 #define __GEDIT_UTILS_H__
 
-#include <glib.h>
-#include <gtk/gtk.h>
-#include <atk/atk.h>
-#include <gedit/gedit-document.h>
 #include <gtksourceview/gtksource.h>
 
 G_BEGIN_DECLS
@@ -131,11 +127,6 @@ gchar           *gedit_utils_set_direct_save_filename	(GdkDragContext *context);
 
 const gchar     *gedit_utils_newline_type_to_string	(GtkSourceNewlineType newline_type);
 
-/* Private */
-GSList		*_gedit_utils_encoding_strv_to_list	(const gchar * const *enc_str);
-
-gchar	       **_gedit_utils_encoding_list_to_strv	(const GSList *enc_list);
-
 G_END_DECLS
 
 #endif /* __GEDIT_UTILS_H__ */
